<?php
function hr_office_vacancy_license_menu() {  
  add_submenu_page('edit.php?post_type=hroffice_vacn_shortc', __('Plugin License','hr_office_vacancy_domain'), __('Plugin License','hr_office_vacancy_domain'), "manage_options", 'license_configuration', 'hr_office_vacancy_license_page', '');
}
add_action('admin_menu', 'hr_office_vacancy_license_menu');

function hr_office_vacancy_license_page() {
  $license = get_option( 'hr_office_vacancy_plugin_license_key' );
  $status  = get_option( 'hr_office_vacancy_plugin_license_status' );
  ?>
  <div class="wrap hr_office_vacancy_license_key_settings">
    <h3 class="settings-title"></h3>
    <?php settings_errors(); ?>
    
    <div class="card">
      <div class="overlay"></div>
      <form method="post" action="options.php">
        <?php settings_fields('hr_office_vacancy_license_settings_field'); ?>

        <div class="logo-div">  
          <img src="<?php echo plugin_dir_url( __DIR__ ); ?>assets/img/logo.png">  
          <p><?php _e('Thank you for choosing HROffice - Boost your business through technology. Use our WordPress Plugin for your Vacancy Listing.','hr_office_vacancy_domain'); ?></p>
        </div>
        <div class="licence-form-div">  
          <?php if( $status != 'valid' ) { ?>   
            <p class="enter-text"><?php _e('Enter your License key to enable all features of the plugin.','hr_office_vacancy_domain'); ?></p>
          <?php } ?>

          <?php do_action( 'admin_notices' ); ?>

          <div class="licence-form-check">
              <div class="field">
                  <input id="hr_office_vacancy_plugin_license_key" name="hr_office_vacancy_plugin_license_key" type="text" required <?php if( $status !== false && $status == 'valid' ) {echo 'disabled';} ?> class="regular-text" placeholder="<?php _e('Enter your License key Here','hr_office_vacancy_domain'); ?>" value="<?php esc_attr_e( $license ); ?>" />
                  <?php if( $status !== false && $status == 'valid' ) { ?>
                    <span class="dashicons dashicons-yes-alt valid-mark-yes"></span>
                  <?php } ?>
              </div>
              <div class="btn">
                  <?php if( $status !== false && $status == 'valid' ) { ?>
                    <a href="" class="button-secondary open"><?php _e('Deactivate License','hr_office_vacancy_domain'); ?></a>
                  <?php } else {
                    wp_nonce_field( 'edd_sample_nonce', 'edd_sample_nonce' ); ?>
                    <input type="submit" class="button-secondary" name="hr_office_vacancy_license_activate_button" value="<?php _e('Validate License','hr_office_vacancy_domain'); ?>"/>
                  <?php } ?>
              </div>          
          </div>
          <p class="contact-text"><?php _e("Don't have a license key or need to renew? Visit","hr_office_vacancy_domain"); ?> <a target="_blank" href="https://hroffice.eu">https://hroffice.eu</a></p>
        </div>  

        <!--Creates the popup body-->
        <div class="popup-overlay">          
          <div class="popup-content">            
            <p><?php _e("Are you sure you want to deactivate?","hr_office_vacancy_domain"); ?></p>

            <?php wp_nonce_field( 'edd_sample_nonce', 'edd_sample_nonce' ); ?>
            <input type="submit" class="confirm-btn" name="hr_office_vacancy_license_deactivate_button" value="<?php _e('Yes','hr_office_vacancy_domain'); ?>"/>            
            <a href="" class="close"><?php _e('No','hr_office_vacancy_domain'); ?></a> 
          </div>
        </div> 

        <?php //submit_button(); ?>
      </form>      
    </div>

  </div>
  <script type="text/javascript">
    jQuery(".open").on("click", function(e) {
      e.preventDefault();
      jQuery(".popup-overlay, .popup-content").addClass("active");
      jQuery(".overlay").addClass("active");
    });

    //removes the "active" class to .popup and .popup-content when the "Close" button is clicked 
    jQuery(".close").on("click", function(ev) {
      ev.preventDefault();
      jQuery(".popup-overlay, .popup-content").removeClass("active");
      jQuery(".overlay").removeClass("active");
    });
  </script>  
<?php
}

function hr_office_vacancy_license_register_option() {
  // creates our settings in the options table
  register_setting('hr_office_vacancy_license_settings_field', 'hr_office_vacancy_plugin_license_key', 'hr_office_vacancy_license_sanitize_license_data' );
}
add_action('admin_init', 'hr_office_vacancy_license_register_option');

function hr_office_vacancy_license_sanitize_license_data( $new ) {
  $old = get_option( 'hr_office_vacancy_plugin_license_key' );
  if( $old && $old != $new ) {
    update_option( 'hr_office_vacancy_plugin_license_status', 'invalid' ); // new license has been entered, so must reactivate
  }
  return $new;
}

function hr_office_vacancy_license_activate_license() {

  // listen for our activate button to be clicked
  if( isset( $_POST['hr_office_vacancy_license_activate_button'] ) ) {

    // run a quick security check
    if( ! check_admin_referer( 'edd_sample_nonce', 'edd_sample_nonce' ) )
      return; // get out if we didn't click the Activate button

    // retrieve the license from the database
    update_option( 'hr_office_vacancy_plugin_license_key', $_POST['hr_office_vacancy_plugin_license_key'] );

    $license = get_option( 'hr_office_vacancy_plugin_license_key' );
    $domain_name = $_SERVER['SERVER_NAME'];   

    $url  = 'https://license.nowonline.nl/api/validate-license-key';
    $body = array('domain' => $domain_name, 'license_key' => $license);

    $args = array(
        'method'      => 'POST',
        'timeout'     => 120,
        'sslverify'   => false,
        'headers'     => array(),
        'body'        => $body,
        'blocking'    => true,
        'httpversion' => '1.1',
        'cookies'     => array(),
    );

    $request = wp_remote_post( $url, $args );
    $license_response = json_decode( wp_remote_retrieve_body( $request ) );
    //print_r($license_response->data->license_status); 
    //echo $domain_name;     

    $license_data = $license_response->data->license_status;
   

    switch( $license_data ) {

      case 'expired' :

        $message =  __( 'Your license key expired','hr_office_vacancy_domain' );
        $license_status = 'invalid';
        break;

      case 'valid' :

        $message =  __( 'License Activated.','hr_office_vacancy_domain' );
        $license_status = 'valid'; // will be either "valid" or "invalid"
        break;  

      case 'not_valid' :

        $message = __( 'Your license key not valid.','hr_office_vacancy_domain' );
        $license_status = 'invalid';
        break;      

      default :

        $message = __( 'An error occurred, please try again.','hr_office_vacancy_domain' );
        $license_status = 'invalid';
        break;
    }

    $referral_status = $license_response->data->referral_status;

    update_option( 'hr_office_vacancy_plugin_license_status', $license_status );
    update_option( 'hr_office_vacancy_referral_license_status', $referral_status );
    $base_url = admin_url( 'edit.php?post_type=hroffice_vacn_shortc&page=license_configuration' );

    // Check if anything passed on a message constituting a failure
    if ( $license_status == 'invalid' ) {      
      $redirect = add_query_arg( array( 'sl_activation' => 'false', 'message' => urlencode( $message ) ), $base_url );
      wp_redirect( $redirect );
      exit();
    }else{      
      $redirect = add_query_arg( array( 'sl_activation' => 'true', 'message' => urlencode( $message ) ), $base_url );
      wp_redirect( $redirect );
      exit();
    }

    
  }

  if( isset( $_POST['hr_office_vacancy_license_deactivate_button'] ) ){
    
    delete_option( 'hr_office_vacancy_plugin_license_status' );
    delete_option( 'hr_office_vacancy_plugin_license_key' ); 
    delete_option( 'hr_office_vacancy_referral_license_status' );   

    $message = __( 'License Deactivated.','hr_office_vacancy_domain' );
    $base_url = admin_url( 'edit.php?post_type=hroffice_vacn_shortc&page=license_configuration' );

    $redirect = add_query_arg( array( 'sl_activation' => 'true', 'message' => urlencode( $message ) ), $base_url );
    wp_redirect( $redirect );
    exit();
    
  }

}
add_action('admin_init', 'hr_office_vacancy_license_activate_license');

function hr_office_vacancy_license_admin_notices() {
  if ( isset( $_GET['sl_activation'] ) && ! empty( $_GET['message'] ) ) {

    switch( $_GET['sl_activation'] ) {

      case 'false':
        $message = urldecode( $_GET['message'] );
        ?>
        <div class="notice notice-error settings-error is-dismissible">
          <p><?php echo $message; ?></p>
        </div>
        <?php
        break;

      case 'true':
        $message = urldecode( $_GET['message'] );      
        ?>
        <div class="notice notice-success settings-error is-dismissible">
          <p><?php echo $message; ?></p>
        </div>
        <?php        
        break;

      default: 

    }
  }
}
add_action( 'admin_notices', 'hr_office_vacancy_license_admin_notices' );